@@ -38,6 +38,10 @@ const conf: RouteProps[] = [
       },
     ],
   },
+  {
+    path: '/dataTemplate',
+    component: () => import('@/ui/pages/GroupDataTemplate'),
+  },
   {
     path: '/consume',
     component: () => import('@/ui/pages/ConsumeDashboard'),
