@@ -29,7 +29,6 @@ export interface State {
   userId: number;
   roles: string[];
   tenant: string;
-  tenantList: string[];
   currentMenu: null | Omit<MenuItemType, 'children'>;
 }
 
@@ -39,7 +38,6 @@ const state: State = {
   userId: 0,
   roles: [],
   tenant: '',
-  tenantList: [],
   currentMenu: null,
 };
 
@@ -61,13 +59,6 @@ const reducers = {
     };
   },
 
-  setTenantInfo(state, payload) {
-    return {
-      ...state,
-      tenantList: payload.tenantList,
-    };
-  },
-
   setCurrentMenu(state, payload) {
     const pathname = payload && payload.pathname;
     if (!pathname) return state;
