@@ -19,6 +19,6 @@
 
 import React from 'react';
 import ReactDOM from 'react-dom';
-import App from '@/App';
+import App from '@/core/App';
 
 ReactDOM.render(<App />, document.getElementById('root'));
