@@ -24,7 +24,7 @@ import { SourceInfo } from '../common/SourceInfo';
 import i18n from '@/i18n';
 
 const { I18n } = DataWithBackend;
-const { FieldDecorator, SyncField } = RenderRow;
+const { FieldDecorator, SyncField, IngestionField } = RenderRow;
 const { ColumnDecorator } = RenderList;
 
 export default class OracleSource
@@ -40,6 +40,7 @@ export default class OracleSource
   })
   @ColumnDecorator()
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Oracle.Hostname')
   hostname: string;
 
@@ -55,6 +56,7 @@ export default class OracleSource
   })
   @ColumnDecorator()
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Oracle.Port')
   port: number;
 
@@ -67,6 +69,7 @@ export default class OracleSource
   })
   @ColumnDecorator()
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Oracle.Username')
   username: string;
 
@@ -78,6 +81,7 @@ export default class OracleSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Oracle.Password')
   password: string;
 
@@ -89,6 +93,7 @@ export default class OracleSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Oracle.Database')
   database: string;
 
@@ -100,6 +105,7 @@ export default class OracleSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Oracle.SchemaName')
   schemaName: string;
 
@@ -111,6 +117,7 @@ export default class OracleSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Oracle.TableName')
   tableName: string;
 
@@ -133,6 +140,7 @@ export default class OracleSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Oracle.AllMigration')
   allMigration: boolean;
 
@@ -155,6 +163,7 @@ export default class OracleSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Oracle.ScanStartupMode')
   scanStartupMode: string;
 
@@ -165,6 +174,7 @@ export default class OracleSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Oracle.PrimaryKey')
   primaryKey: string;
 }
