@@ -25,6 +25,7 @@ import EditableTable from '@/ui/components/EditableTable';
 import { fieldTypes as sourceFieldsTypes } from '@/plugins/sinks/common/sourceFields';
 import { statusList, genStatusTag } from './status';
 import { timestampFormat } from '@/core/utils';
+import HighRadio from '@/ui/components/HighRadio';
 
 const { I18nMap, I18n } = DataWithBackend;
 const { FieldList, FieldDecorator } = RenderRow;
@@ -80,12 +81,6 @@ export class StreamDefaultInfo implements DataWithBackend, RenderRow, RenderList
   @I18n('basic.Modifier')
   readonly modifier: string;
 
-  @ColumnDecorator({
-    render: text => timestampFormat(text),
-  })
-  @I18n('basic.CreateTime')
-  readonly createTime: string;
-
   @FieldDecorator({
     type: 'select',
     props: {
@@ -173,10 +168,10 @@ export class StreamDefaultInfo implements DataWithBackend, RenderRow, RenderList
   dataEncoding: string;
 
   @FieldDecorator({
-    type: 'radio',
+    type: HighRadio,
+    initialValue: '124',
     props: values => ({
       disabled: [110].includes(values?.status),
-      initialValue: '124',
       options: [
         {
           label: i18n.t('meta.Stream.DataSeparator.Space'),
@@ -203,6 +198,21 @@ export class StreamDefaultInfo implements DataWithBackend, RenderRow, RenderList
           value: '34',
         },
       ],
+      useInput: true,
+      useInputProps: {
+        style:
+          i18n?.language === 'cn'
+            ? {
+                width: 80,
+              }
+            : {
+                width: 80,
+                position: 'absolute',
+                left: 180,
+                bottom: 0,
+              },
+        placeholder: 'ASCII',
+      },
     }),
     rules: [
       {
