@@ -135,6 +135,10 @@ const Comp: React.FC = () => {
           allowClear: true,
           options: lastConsumerStatusList,
           dropdownMatchSelectWidth: false,
+          showSearch: true,
+          filterOption: (keyword: string, option: { label: any }) => {
+            return (option?.label ?? '').toLowerCase().includes(keyword.toLowerCase());
+          },
         },
       },
       {
@@ -146,6 +150,10 @@ const Comp: React.FC = () => {
           allowClear: true,
           options: consumes.filter(x => x.value),
           dropdownMatchSelectWidth: false,
+          showSearch: true,
+          filterOption: (keyword: string, option: { label: any }) => {
+            return (option?.label ?? '').toLowerCase().includes(keyword.toLowerCase());
+          },
         },
       },
     ],
