@@ -23,6 +23,8 @@ import dayjs from 'dayjs';
 import i18n from '@/i18n';
 import { sinks } from '@/plugins/sinks';
 import request from '@/core/utils/request';
+import { CSVLink } from 'react-csv';
+import audit from '@/ui/pages/GroupDetail/Audit/index';
 
 export const timeStaticsDimList = [
   {
@@ -131,11 +133,11 @@ export const getSourceDataWithPercent = (sourceKeys, sourceMap) => {
 
 export const getDiff = (first, current) => {
   if (first === 0) {
-    return '0%';
+    return first.toFixed(4) + '%';
   }
   let result;
-  const diff = Math.ceil((current / first - 1) * 100);
-  result = diff > 0 ? '+' + diff + '%' : diff + '%';
+  const diff = (current / first - 1) * 100;
+  result = diff > 0 ? '+' + diff.toFixed(4) + '%' : diff.toFixed(4) + '%';
   return result;
 };
 
@@ -154,10 +156,18 @@ export const getSourceDataWithCommas = sourceData => {
   });
   return sourceData;
 };
-
 let endTimeVisible = true;
-
-export const getFormContent = (inlongGroupId, initialValues, onSearch, onDataStreamSuccess) => [
+export const getFormContent = (
+  inlongGroupId,
+  initialValues,
+  onSearch,
+  onDataStreamSuccess,
+  sourceData,
+  csvData,
+  fileName,
+  setInlongStreamID,
+  inlongStreamId,
+) => [
   {
     type: 'select',
     label: i18n.t('pages.ModuleAudit.config.InlongStreamId'),
@@ -165,6 +175,9 @@ export const getFormContent = (inlongGroupId, initialValues, onSearch, onDataStr
     props: {
       dropdownMatchSelectWidth: false,
       showSearch: true,
+      onChange: (value, option) => {
+        setInlongStreamID(value);
+      },
       options: {
         requestAuto: true,
         requestTrigger: ['onOpen', 'onSearch'],
@@ -207,7 +220,7 @@ export const getFormContent = (inlongGroupId, initialValues, onSearch, onDataStr
             pageNum: 1,
             pageSize: 100,
             inlongGroupId,
-            inlongStreamId: values.inlongStreamId,
+            inlongStreamId: inlongStreamId,
           },
         }),
         requestParams: {
@@ -218,6 +231,9 @@ export const getFormContent = (inlongGroupId, initialValues, onSearch, onDataStr
             })) || [],
         },
       },
+      filterOption: (keyword: string, option: { label: any }) => {
+        return (option?.label ?? '').toLowerCase().includes(keyword.toLowerCase());
+      },
     }),
   },
   {
@@ -244,7 +260,6 @@ export const getFormContent = (inlongGroupId, initialValues, onSearch, onDataStr
             return Promise.resolve();
           }
           const timeDiff = value - getFieldValue('startDate');
-          console.log('timeDiff', value, getFieldValue('startDate'), timeDiff);
           if (timeDiff >= 0) {
             const isHourDiff = dim === 'HOUR' && timeDiff < 1000 * 60 * 60 * 24 * 3;
             const isDayDiff = dim === 'DAY' && timeDiff < 1000 * 60 * 60 * 24 * 7;
@@ -332,6 +347,15 @@ export const getFormContent = (inlongGroupId, initialValues, onSearch, onDataStr
       </Button>
     ),
   },
+  {
+    type: (
+      <Button type="primary" disabled={!(sourceData.length > 0)}>
+        <CSVLink data={csvData} filename={fileName}>
+          {i18n.t('pages.GroupDetail.Audit.ExportCSV')}
+        </CSVLink>
+      </Button>
+    ),
+  },
 ];
 
 export const getTableColumns = (source, dim) => {
