@@ -37,8 +37,6 @@ public class ConfigConstants {
 
     public static final String TOPIC = "topic";
 
-    public static final String ATTR = "attr";
-
     public static final String FILTER_EMPTY_MSG = "filter-empty-msg";
 
     public static final String TCP_NO_DELAY = "tcpNoDelay";
@@ -78,6 +76,7 @@ public class ConfigConstants {
     public static final String REMOTE_IP_KEY = "srcIp";
     public static final String DATAPROXY_IP_KEY = "dpIp";
     public static final String MSG_ENCODE_VER = "msgEnType";
+    public static final String MSG_SEND_TIME = "st";
     public static final String REMOTE_IDC_KEY = "idc";
     public static final String MSG_COUNTER_KEY = "msgcnt";
     public static final String PKG_COUNTER_KEY = "pkgcnt";
