@@ -206,10 +206,23 @@ public class PulsarHandler implements MessageQueueHandler {
         String producerTopic = null;
         try {
             // get idConfig
-            IdTopicConfig idConfig = ConfigManager.getInstance().getIdTopicConfig(
+            IdTopicConfig idConfig = ConfigManager.getInstance().getSinkIdTopicConfig(
                     profile.getInlongGroupId(), profile.getInlongStreamId());
             if (idConfig == null) {
-                if (!CommonConfigHolder.getInstance().isEnableUnConfigTopicAccept()) {
+                // add default topics first
+                if (CommonConfigHolder.getInstance().isEnableUnConfigTopicAccept()) {
+                    producerTopic = CommonConfigHolder.getInstance().getRandDefTopics();
+                    if (StringUtils.isEmpty(producerTopic)) {
+                        sinkContext.fileMetricIncWithDetailStats(
+                                StatConstants.EVENT_SINK_DEFAULT_TOPIC_MISSING, profile.getUid());
+                        sinkContext.addSendResultMetric(profile, clusterName, profile.getUid(), false, 0);
+                        sinkContext.getMqZoneSink().releaseAcquiredSizePermit(profile);
+                        profile.fail(DataProxyErrCode.GROUPID_OR_STREAMID_NOT_CONFIGURE, "");
+                        return false;
+                    }
+                    sinkContext.fileMetricIncWithDetailStats(
+                            StatConstants.EVENT_SINK_DEFAULT_TOPIC_USED, profile.getUid());
+                } else {
                     sinkContext.fileMetricIncWithDetailStats(
                             StatConstants.EVENT_SINK_CONFIG_TOPIC_MISSING, profile.getUid());
                     sinkContext.addSendResultMetric(profile, clusterName, profile.getUid(), false, 0);
@@ -217,15 +230,6 @@ public class PulsarHandler implements MessageQueueHandler {
                     profile.fail(DataProxyErrCode.GROUPID_OR_STREAMID_NOT_CONFIGURE, "");
                     return false;
                 }
-                producerTopic = CommonConfigHolder.getInstance().getRandDefTopics();
-                if (StringUtils.isEmpty(producerTopic)) {
-                    sinkContext.fileMetricIncSumStats(StatConstants.EVENT_SINK_DEFAULT_TOPIC_MISSING);
-                    sinkContext.addSendResultMetric(profile, clusterName, profile.getUid(), false, 0);
-                    sinkContext.getMqZoneSink().releaseAcquiredSizePermit(profile);
-                    profile.fail(DataProxyErrCode.GROUPID_OR_STREAMID_NOT_CONFIGURE, "");
-                    return false;
-                }
-                sinkContext.fileMetricIncSumStats(StatConstants.EVENT_SINK_DEFAULT_TOPIC_USED);
             } else {
                 producerTopic = idConfig.getPulsarTopicName(tenant, namespace);
             }
@@ -250,13 +254,16 @@ public class PulsarHandler implements MessageQueueHandler {
                 } catch (Throwable ex) {
                     logger.error("create new producer failed", ex);
                 }
-            }
-            // create producer failed
-            if (producer == null) {
-                sinkContext.fileMetricIncWithDetailStats(StatConstants.EVENT_SINK_PRODUCER_NULL, producerTopic);
-                sinkContext.processSendFail(profile, clusterName, producerTopic, 0,
-                        DataProxyErrCode.PRODUCER_IS_NULL, "");
-                return false;
+                // create producer failed
+                if (producer == null) {
+                    sinkContext.fileMetricIncWithDetailStats(
+                            StatConstants.EVENT_SINK_PRODUCER_CREATE_FAILURE, producerTopic);
+                    sinkContext.processSendFail(profile, clusterName, producerTopic, 0,
+                            DataProxyErrCode.PRODUCER_IS_NULL, "");
+                    return false;
+                }
+                sinkContext.fileMetricIncWithDetailStats(
+                        StatConstants.EVENT_SINK_PRODUCER_CREATE_SUCCESS, producerTopic);
             }
             // send
             if (profile instanceof SimplePackProfile) {
@@ -344,29 +351,24 @@ public class PulsarHandler implements MessageQueueHandler {
     private void sendSimplePackProfile(SimplePackProfile simpleProfile, IdTopicConfig idConfig,
             Producer<byte[]> producer,
             String producerTopic) throws Exception {
-        // headers
-        Map<String, String> headers = simpleProfile.getPropsToMQ();
-        // body
-        byte[] bodyBytes = simpleProfile.getEvent().getBody();
         // metric
-        sinkContext.addSendMetric(simpleProfile, clusterName, producerTopic, bodyBytes.length);
+        sinkContext.addSendMetric(simpleProfile, clusterName,
+                producerTopic, simpleProfile.getEvent().getBody().length);
         // sendAsync
         long sendTime = System.currentTimeMillis();
-        CompletableFuture<MessageId> future = producer.newMessage().properties(headers)
-                .value(bodyBytes).sendAsync();
+        CompletableFuture<MessageId> future = producer.newMessage().properties(
+                simpleProfile.getPropsToMQ(sendTime)).value(simpleProfile.getEvent().getBody()).sendAsync();
         // callback
         future.whenCompleteAsync((msgId, ex) -> {
             if (ex != null) {
-                sinkContext.fileMetricIncWithDetailStats(StatConstants.EVENT_SINK_FAILURE, producerTopic);
-                sinkContext.fileMetricAddFailCnt(simpleProfile, producerTopic, msgId.toString());
+                sinkContext.fileMetricAddFailStats(simpleProfile, producerTopic, msgId.toString(), producerTopic);
                 sinkContext.processSendFail(simpleProfile, clusterName, producerTopic, sendTime,
                         DataProxyErrCode.MQ_RETURN_ERROR, ex.getMessage());
                 if (logCounter.shouldPrint()) {
                     logger.error("Send SimpleProfileV0 to Pulsar failure", ex);
                 }
             } else {
-                sinkContext.fileMetricAddSuccCnt(simpleProfile, producerTopic, msgId.toString());
-                sinkContext.fileMetricIncSumStats(StatConstants.EVENT_SINK_SUCCESS);
+                sinkContext.fileMetricAddSuccStats(simpleProfile, producerTopic, "");
                 sinkContext.addSendResultMetric(simpleProfile, clusterName, producerTopic, true, sendTime);
                 sinkContext.getMqZoneSink().releaseAcquiredSizePermit(simpleProfile);
                 simpleProfile.ack();
