@@ -22,6 +22,7 @@ import org.apache.inlong.manager.common.util.Preconditions;
 public enum FieldType {
 
     INT,
+    INTEGER,
     TINYINT,
     SMALLINT,
     BIGINT,
@@ -35,6 +36,7 @@ public enum FieldType {
     FIXED,
     BYTE,
     BINARY,
+    CHAR,
     VARCHAR,
     VARBINARY,
     BOOLEAN,
@@ -44,6 +46,8 @@ public enum FieldType {
     INT16,
     INT32,
     INT64,
+    FLOAT4,
+    FLOAT8,
     FLOAT32,
     FLOAT64,
     DATETIME,
@@ -54,7 +58,9 @@ public enum FieldType {
     MAP,
     STRUCT,
     FUNCTION,
-    KEYWORD;
+    KEYWORD,
+    LARGEINT,
+    JSON;
 
     public static FieldType forName(String name) {
         Preconditions.expectNotBlank(name, ErrorCodeEnum.INVALID_PARAMETER, "FieldType should not be null");
