@@ -53,4 +53,10 @@ public interface InlongConsumeEntityMapper {
 
     int deleteById(Integer id);
 
+    @MultiTenantQuery(with = false)
+    int migrate(@Param("groupId") String groupId, @Param("sourceTenant") String sourceTenant,
+            @Param("targetTenant") String targetTenant);
+
+    List<InlongConsumeEntity> selectByGroupId(String groupId);
+
 }
