@@ -17,15 +17,18 @@
 
 package org.apache.inlong.manager.pojo.cluster.agent;
 
+import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
+import org.apache.inlong.manager.common.exceptions.BusinessException;
+import org.apache.inlong.manager.common.util.CommonBeanUtils;
+import org.apache.inlong.manager.common.util.JsonUtils;
+
 import io.swagger.annotations.ApiModel;
 import io.swagger.annotations.ApiModelProperty;
 import lombok.AllArgsConstructor;
 import lombok.Builder;
 import lombok.Data;
 import lombok.NoArgsConstructor;
-import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
-import org.apache.inlong.manager.common.exceptions.BusinessException;
-import org.apache.inlong.manager.common.util.JsonUtils;
+import org.apache.commons.lang3.StringUtils;
 
 import javax.validation.constraints.NotNull;
 
@@ -45,10 +48,11 @@ public class AgentClusterDTO {
     /**
      * Get the dto instance from the request
      */
-    public static AgentClusterDTO getFromRequest(AgentClusterRequest request) {
-        return AgentClusterDTO.builder()
-                .serverVersion(request.getServerVersion())
-                .build();
+    public static AgentClusterDTO getFromRequest(AgentClusterRequest request, String extParams) {
+        AgentClusterDTO dto = StringUtils.isNotBlank(extParams)
+                ? AgentClusterDTO.getFromJson(extParams)
+                : new AgentClusterDTO();
+        return CommonBeanUtils.copyProperties(request, dto, true);
     }
 
     /**
