@@ -17,7 +17,6 @@
 
 package org.apache.inlong.manager.pojo.source.kafka;
 
-import org.apache.inlong.common.enums.MessageWrapType;
 import org.apache.inlong.manager.common.consts.SourceType;
 import org.apache.inlong.manager.common.util.CommonBeanUtils;
 import org.apache.inlong.manager.common.util.JsonTypeDefine;
@@ -90,11 +89,14 @@ public class KafkaSource extends StreamSource {
     @ApiModelProperty(value = "Data separator")
     private String dataSeparator;
 
+    @ApiModelProperty(value = "KV separator")
+    private String kvSeparator;
+
     @ApiModelProperty(value = "Data field escape symbol")
     private String dataEscapeChar;
 
     @ApiModelProperty(value = "The message body wrap  wrap type, including: RAW, INLONG_MSG_V0, INLONG_MSG_V1, etc")
-    private String wrapType = MessageWrapType.INLONG_MSG_V0.getName();
+    private String wrapType;
 
     public KafkaSource() {
         this.setSourceType(SourceType.KAFKA);
