@@ -109,6 +109,9 @@ public class MySQLBinlogSourceDTO {
     @ApiModelProperty("Whether to migrate all databases")
     private boolean allMigration;
 
+    @ApiModelProperty("Only incremental")
+    private boolean onlyIncremental;
+
     @ApiModelProperty("Primary key must be shared by all tables")
     private String primaryKey;
 
