@@ -17,8 +17,13 @@
 
 package org.apache.inlong.manager.pojo.user;
 
+import org.apache.inlong.manager.common.enums.InlongUserTypeEnum;
+import org.apache.inlong.manager.common.enums.TenantUserTypeEnum;
+
 import lombok.extern.slf4j.Slf4j;
 
+import java.util.Set;
+
 /**
  * User info for login
  */
@@ -34,6 +39,12 @@ public class LoginUserUtils {
         return LOGIN_USER_DETAIL_TL.get();
     }
 
+    public static boolean isInlongAdminOrTenantAdmin() {
+        Set<String> roles = LOGIN_USER_DETAIL_TL.get().getRoles();
+        return roles.contains(TenantUserTypeEnum.TENANT_ADMIN.name()) || roles.contains(
+                InlongUserTypeEnum.INLONG_ADMIN.name());
+    }
+
     public static void setUserLoginInfo(UserInfo userInfo) {
         LOGIN_USER_DETAIL_TL.set(userInfo);
         log.debug("user login: {}", userInfo.getName());
