@@ -21,11 +21,14 @@ import org.apache.inlong.common.enums.DataTypeEnum;
 import org.apache.inlong.common.enums.MessageWrapType;
 import org.apache.inlong.common.msg.AttributeConstants;
 import org.apache.inlong.common.msg.InLongMsg;
+import org.apache.inlong.common.pojo.sort.dataflow.deserialization.DeserializationConfig;
+import org.apache.inlong.common.pojo.sort.dataflow.deserialization.InlongMsgDeserializationConfig;
 import org.apache.inlong.common.util.StringUtil;
 import org.apache.inlong.manager.common.exceptions.BusinessException;
 import org.apache.inlong.manager.pojo.consume.BriefMQMessage;
 import org.apache.inlong.manager.pojo.consume.BriefMQMessage.FieldInfo;
 import org.apache.inlong.manager.pojo.stream.InlongStreamInfo;
+import org.apache.inlong.manager.pojo.stream.QueryMessageRequest;
 import org.apache.inlong.manager.service.datatype.DataTypeOperator;
 import org.apache.inlong.manager.service.datatype.DataTypeOperatorFactory;
 
@@ -34,7 +37,6 @@ import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Service;
 
 import java.nio.charset.Charset;
-import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
@@ -53,11 +55,10 @@ public class InlongMsgDeserializeOperator implements DeserializeOperator {
     }
 
     @Override
-    public List<BriefMQMessage> decodeMsg(InlongStreamInfo streamInfo, byte[] msgBytes, Map<String, String> headers,
-            int index) {
+    public List<BriefMQMessage> decodeMsg(InlongStreamInfo streamInfo, List<BriefMQMessage> messageList,
+            byte[] msgBytes, Map<String, String> headers, int index, QueryMessageRequest request) {
         String groupId = headers.get(AttributeConstants.GROUP_ID);
         String streamId = headers.get(AttributeConstants.STREAM_ID);
-        List<BriefMQMessage> messageList = new ArrayList<>();
         InLongMsg inLongMsg = InLongMsg.parseFrom(msgBytes);
         for (String attr : inLongMsg.getAttrs()) {
             Map<String, String> attrMap = StringUtil.splitKv(attr, INLONGMSG_ATTR_ENTRY_DELIMITER,
@@ -85,6 +86,9 @@ public class InlongMsgDeserializeOperator implements DeserializeOperator {
                     DataTypeOperator dataTypeOperator =
                             dataTypeOperatorFactory.getInstance(DataTypeEnum.forType(streamInfo.getDataType()));
                     List<FieldInfo> streamFieldList = dataTypeOperator.parseFields(body, streamInfo);
+                    if (checkIfFilter(request, streamFieldList)) {
+                        continue;
+                    }
                     BriefMQMessage message = BriefMQMessage.builder()
                             .id(index)
                             .inlongGroupId(groupId)
@@ -92,6 +96,7 @@ public class InlongMsgDeserializeOperator implements DeserializeOperator {
                             .dt(msgTime)
                             .clientIp(attrMap.get(CLIENT_IP))
                             .headers(headers)
+                            .attribute(attr)
                             .body(body)
                             .fieldList(streamFieldList)
                             .build();
@@ -105,4 +110,11 @@ public class InlongMsgDeserializeOperator implements DeserializeOperator {
         }
         return messageList;
     }
+
+    @Override
+    public DeserializationConfig getDeserializationConfig(InlongStreamInfo streamInfo) {
+        InlongMsgDeserializationConfig inlongMsgDeserializationConfig = new InlongMsgDeserializationConfig();
+        inlongMsgDeserializationConfig.setStreamId(streamInfo.getInlongStreamId());
+        return inlongMsgDeserializationConfig;
+    }
 }
