@@ -59,8 +59,6 @@ import org.apache.inlong.manager.pojo.group.pulsar.InlongPulsarDTO;
 import org.apache.inlong.manager.pojo.source.DataAddTaskRequest;
 import org.apache.inlong.manager.pojo.source.SourceRequest;
 import org.apache.inlong.manager.pojo.source.StreamSource;
-import org.apache.inlong.manager.pojo.source.cos.COSSourceDTO;
-import org.apache.inlong.manager.pojo.source.file.FileSourceDTO;
 import org.apache.inlong.manager.pojo.stream.InlongStreamInfo;
 import org.apache.inlong.manager.pojo.stream.StreamField;
 import org.apache.inlong.manager.service.node.DataNodeService;
@@ -545,26 +543,7 @@ public abstract class AbstractSourceOperator implements StreamSourceOperator {
                             ? TaskStateEnum.RUNNING.getType()
                             : TaskStateEnum.FROZEN.getType());
             dataConfig.setSyncSend(streamEntity.getSyncSend());
-            if (SourceType.FILE.equalsIgnoreCase(entity.getSourceType())) {
-                String dataSeparator = String.valueOf((char) Integer.parseInt(streamEntity.getDataSeparator()));
-                FileSourceDTO fileSourceDTO = JsonUtils.parseObject(extParams, FileSourceDTO.class);
-                if (Objects.nonNull(fileSourceDTO)) {
-                    fileSourceDTO.setDataSeparator(dataSeparator);
-                    dataConfig.setAuditVersion(fileSourceDTO.getAuditVersion());
-                    fileSourceDTO.setDataContentStyle(streamEntity.getDataType());
-                    extParams = JsonUtils.toJsonString(fileSourceDTO);
-                }
-            }
-            if (SourceType.COS.equalsIgnoreCase(entity.getSourceType())) {
-                String dataSeparator = String.valueOf((char) Integer.parseInt(streamEntity.getDataSeparator()));
-                COSSourceDTO cosSourceDTO = JsonUtils.parseObject(extParams, COSSourceDTO.class);
-                if (Objects.nonNull(cosSourceDTO)) {
-                    cosSourceDTO.setDataSeparator(dataSeparator);
-                    dataConfig.setAuditVersion(cosSourceDTO.getAuditVersion());
-                    cosSourceDTO.setContentStyle(streamEntity.getDataType());
-                    extParams = JsonUtils.toJsonString(cosSourceDTO);
-                }
-            }
+            extParams = sourceOperator.updateDataConfig(extParams, streamEntity, dataConfig);
             InlongStreamInfo streamInfo = CommonBeanUtils.copyProperties(streamEntity, InlongStreamInfo::new);
             // Processing extParams
             unpackExtParams(streamEntity.getExtParams(), streamInfo);
