@@ -17,7 +17,6 @@
 
 package org.apache.inlong.manager.service.source.mqtt;
 
-import com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.inlong.manager.common.consts.SourceType;
 import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
 import org.apache.inlong.manager.common.exceptions.BusinessException;
@@ -30,6 +29,8 @@ import org.apache.inlong.manager.pojo.source.mqtt.MqttSourceDTO;
 import org.apache.inlong.manager.pojo.source.mqtt.MqttSourceRequest;
 import org.apache.inlong.manager.pojo.stream.StreamField;
 import org.apache.inlong.manager.service.source.AbstractSourceOperator;
+
+import com.fasterxml.jackson.databind.ObjectMapper;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Service;
 
@@ -56,7 +57,7 @@ public class MqttSourceOperator extends AbstractSourceOperator {
         MqttSourceRequest sourceRequest = (MqttSourceRequest) request;
         CommonBeanUtils.copyProperties(sourceRequest, targetEntity, true);
         try {
-            MqttSourceDTO dto = MqttSourceDTO.getFromRequest(sourceRequest);
+            MqttSourceDTO dto = MqttSourceDTO.getFromRequest(sourceRequest, targetEntity.getExtParams());
             targetEntity.setExtParams(objectMapper.writeValueAsString(dto));
         } catch (Exception e) {
             throw new BusinessException(ErrorCodeEnum.SOURCE_INFO_INCORRECT,
