@@ -19,7 +19,6 @@ package org.apache.inlong.manager.service.transform;
 
 import org.apache.inlong.manager.common.consts.InlongConstants;
 import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
-import org.apache.inlong.manager.common.enums.GroupStatus;
 import org.apache.inlong.manager.common.exceptions.BusinessException;
 import org.apache.inlong.manager.common.util.CommonBeanUtils;
 import org.apache.inlong.manager.common.util.Preconditions;
@@ -102,40 +101,6 @@ public class StreamTransformServiceImpl implements StreamTransformService {
         return transformEntity.getId();
     }
 
-    @Override
-    @Transactional(rollbackFor = Throwable.class, propagation = Propagation.REQUIRES_NEW)
-    public Integer save(TransformRequest request, UserInfo opInfo) {
-        // Check if it can be added
-        InlongGroupEntity groupEntity = groupMapper.selectByGroupId(request.getInlongGroupId());
-        if (groupEntity == null) {
-            throw new BusinessException(ErrorCodeEnum.GROUP_NOT_FOUND,
-                    String.format("InlongGroup does not exist with InlongGroupId=%s", request.getInlongGroupId()));
-        }
-        // check inlong group status
-        GroupStatus status = GroupStatus.forCode(groupEntity.getStatus());
-        if (GroupStatus.notAllowedUpdate(status)) {
-            throw new BusinessException(ErrorCodeEnum.OPT_NOT_ALLOWED_BY_STATUS,
-                    String.format(ErrorCodeEnum.OPT_NOT_ALLOWED_BY_STATUS.getMessage(), status));
-        }
-        // Check if the record to be added exists
-        List<StreamTransformEntity> transformEntities =
-                transformMapper.selectByRelatedId(request.getInlongGroupId(),
-                        request.getInlongStreamId(), request.getTransformName());
-        if (CollectionUtils.isNotEmpty(transformEntities)) {
-            throw new BusinessException(ErrorCodeEnum.RECORD_DUPLICATE,
-                    String.format("stream transform already exists with groupId=%s, streamId=%s, transformName=%s",
-                            request.getInlongGroupId(), request.getInlongStreamId(), request.getTransformName()));
-        }
-        // add record
-        StreamTransformEntity transformEntity =
-                CommonBeanUtils.copyProperties(request, StreamTransformEntity::new);
-        transformEntity.setCreator(opInfo.getName());
-        transformEntity.setModifier(opInfo.getName());
-        transformMapper.insert(transformEntity);
-        saveFieldOpt(transformEntity, request.getFieldList());
-        return transformEntity.getId();
-    }
-
     @Override
     public PageResult<TransformResponse> listByCondition(TransformPageRequest request, UserInfo opInfo) {
         String groupId = request.getInlongGroupId();
@@ -195,23 +160,6 @@ public class StreamTransformServiceImpl implements StreamTransformService {
         return getTransformResponse(entityList);
     }
 
-    @Override
-    public List<TransformResponse> listTransform(String groupId, String streamId, UserInfo opInfo) {
-        // Check if it can be added
-        InlongGroupEntity groupEntity = groupMapper.selectByGroupId(groupId);
-        if (groupEntity == null) {
-            throw new BusinessException(ErrorCodeEnum.GROUP_NOT_FOUND,
-                    String.format("InlongGroup does not exist with InlongGroupId=%s", groupId));
-        }
-        // query result
-        List<StreamTransformEntity> entityList = transformMapper.selectByRelatedId(groupId, streamId, null);
-        if (CollectionUtils.isEmpty(entityList)) {
-            return Collections.emptyList();
-        }
-        // get transform data
-        return getTransformResponse(entityList);
-    }
-
     @Override
     @Transactional(rollbackFor = Throwable.class, propagation = Propagation.REQUIRES_NEW)
     public Boolean update(TransformRequest request, String operator) {
@@ -238,38 +186,6 @@ public class StreamTransformServiceImpl implements StreamTransformService {
         return true;
     }
 
-    @Override
-    @Transactional(rollbackFor = Throwable.class, propagation = Propagation.REQUIRES_NEW)
-    public Boolean update(TransformRequest request, UserInfo opInfo) {
-        // check request and parameters
-        this.chkUnmodifiableParams(request);
-        // Check if it can be added
-        InlongGroupEntity groupEntity = groupMapper.selectByGroupId(request.getInlongGroupId());
-        if (groupEntity == null) {
-            throw new BusinessException(ErrorCodeEnum.GROUP_NOT_FOUND,
-                    String.format("InlongGroup does not exist with InlongGroupId=%s", request.getInlongGroupId()));
-        }
-        // check inlong group status
-        GroupStatus status = GroupStatus.forCode(groupEntity.getStatus());
-        if (GroupStatus.notAllowedUpdate(status)) {
-            throw new BusinessException(ErrorCodeEnum.OPT_NOT_ALLOWED_BY_STATUS,
-                    String.format(ErrorCodeEnum.OPT_NOT_ALLOWED_BY_STATUS.getMessage(), status));
-        }
-        // update record
-        StreamTransformEntity transformEntity =
-                CommonBeanUtils.copyProperties(request, StreamTransformEntity::new);
-        transformEntity.setModifier(opInfo.getName());
-        int rowCount = transformMapper.updateByIdSelective(transformEntity);
-        if (rowCount != InlongConstants.AFFECTED_ONE_ROW) {
-            throw new BusinessException(ErrorCodeEnum.CONFIG_EXPIRED,
-                    String.format("transform has already updated with groupId=%s, streamId=%s, name=%s, curVersion=%s",
-                            request.getInlongGroupId(), request.getInlongStreamId(),
-                            request.getTransformName(), request.getVersion()));
-        }
-        updateFieldOpt(transformEntity, request.getFieldList());
-        return true;
-    }
-
     @Override
     @Transactional(rollbackFor = Throwable.class, propagation = Propagation.REQUIRES_NEW)
     public Boolean delete(DeleteTransformRequest request, String operator) {
@@ -303,44 +219,6 @@ public class StreamTransformServiceImpl implements StreamTransformService {
         return true;
     }
 
-    @Override
-    @Transactional(rollbackFor = Throwable.class, propagation = Propagation.REQUIRES_NEW)
-    public Boolean delete(DeleteTransformRequest request, UserInfo opInfo) {
-        // Check if it can be added
-        InlongGroupEntity groupEntity = groupMapper.selectByGroupId(request.getInlongGroupId());
-        if (groupEntity == null) {
-            throw new BusinessException(ErrorCodeEnum.GROUP_NOT_FOUND,
-                    String.format("InlongGroup does not exist with InlongGroupId=%s", request.getInlongGroupId()));
-        }
-        // check inlong group status
-        GroupStatus status = GroupStatus.forCode(groupEntity.getStatus());
-        if (GroupStatus.notAllowedUpdate(status)) {
-            throw new BusinessException(ErrorCodeEnum.OPT_NOT_ALLOWED_BY_STATUS,
-                    String.format(ErrorCodeEnum.OPT_NOT_ALLOWED_BY_STATUS.getMessage(), status));
-        }
-        // query records
-        List<StreamTransformEntity> entityList =
-                transformMapper.selectByRelatedId(request.getInlongGroupId(),
-                        request.getInlongStreamId(), request.getTransformName());
-        if (CollectionUtils.isNotEmpty(entityList)) {
-            for (StreamTransformEntity entity : entityList) {
-                Integer id = entity.getId();
-                entity.setIsDeleted(id);
-                entity.setModifier(opInfo.getName());
-                int rowCount = transformMapper.updateByIdSelective(entity);
-                if (rowCount != InlongConstants.AFFECTED_ONE_ROW) {
-                    throw new BusinessException(ErrorCodeEnum.CONFIG_EXPIRED,
-                            String.format(
-                                    "transform has already updated with groupId=%s, streamId=%s, name=%s, curVersion=%s",
-                                    entity.getInlongGroupId(), entity.getInlongStreamId(),
-                                    entity.getTransformName(), entity.getVersion()));
-                }
-                transformFieldMapper.deleteAll(id);
-            }
-        }
-        return true;
-    }
-
     private List<TransformResponse> getTransformResponse(List<StreamTransformEntity> entityList) {
         List<Integer> transformIds = entityList.stream().map(StreamTransformEntity::getId).collect(Collectors.toList());
         List<StreamTransformFieldEntity> fieldEntities = transformFieldMapper.selectByTransformIds(transformIds);
