@@ -18,6 +18,7 @@
 package org.apache.inlong.manager.web.controller.openapi;
 
 import org.apache.inlong.common.pojo.sdk.SortSourceConfigResponse;
+import org.apache.inlong.common.pojo.sort.SortConfigResponse;
 import org.apache.inlong.common.pojo.sortstandalone.SortClusterResponse;
 import org.apache.inlong.manager.service.core.SortService;
 
@@ -57,4 +58,12 @@ public class SortController {
         return sortService.getSourceConfig(clusterName, sortTaskId, md5);
     }
 
+    @GetMapping("/sort/getSortConfig")
+    @ApiOperation(value = "get sort config")
+    public SortConfigResponse getSortConfig(
+            @RequestParam String clusterName,
+            @RequestParam(required = false) String md5) {
+        return sortService.getSortConfig(clusterName, md5);
+    }
+
 }
