@@ -15,51 +15,48 @@
  * limitations under the License.
  */
 
-#ifndef INLONG_SDK_API_IMP_H
-#define INLONG_SDK_API_IMP_H
+#ifndef INLONG_API_IMP_H
+#define INLONG_API_IMP_H
 
+#include <cstdint>
+#include <functional>
 #include "../config/sdk_conf.h"
 #include "../manager/recv_manager.h"
 #include "../manager/send_manager.h"
 #include "../utils/atomic.h"
-#include <cstdint>
-#include <functional>
 
 namespace inlong {
-
-typedef int (*UserCallBack)(const char *, const char *, const char *, int32_t,
-                            const int64_t, const char *);
+typedef int (*UserCallBack)(const char *, const char *, const char *, int32_t, const int64_t, const char *);
 
 class ApiImp {
-public:
+ public:
   ApiImp();
   ~ApiImp();
   int32_t InitApi(const char *config_file_path);
 
-  int32_t Send(const char *inlong_group_id, const char *inlong_stream_id,
-               const char *msg, int32_t msg_len,
+  int32_t Send(const char *inlong_group_id, const char *inlong_stream_id, const char *msg, int32_t msg_len,
                UserCallBack call_back = nullptr);
 
+  int32_t Send(const char *inlong_group_id, const char *inlong_stream_id, const char *msg, int32_t msg_len,
+               int64_t report_time, UserCallBack call_back = nullptr);
   int32_t CloseApi(int32_t max_waitms);
 
-  int32_t AddInLongGroupId(const std::vector<std::string> &inlong_group_ids);
+  int32_t AddInLongGroupId(const std::vector<std::string> &group_ids);
 
-private:
+ private:
   int32_t DoInit();
   int32_t InitManager();
-  int32_t SendBase(const std::string inlong_group_id,
-                   const std::string inlong_stream_id,
-                   const std::string client_ip, int64_t report_time,
-                   const std::string msg, UserCallBack call_back);
+  int32_t SendBase(const std::string& inlong_group_id, const std::string& inlong_stream_id, const std::string& msg, UserCallBack call_back,
+                   int64_t report_time = 0);
 
-  int32_t CheckData(const std::string inlong_group_id,
-                    const std::string inlong_stream_id, const std::string msg);
+  int32_t CheckData(const std::string& inlong_group_id, const std::string& inlong_stream_id, const std::string& msg);
+
+  int32_t ValidateParams(const char *inlong_group_id, const char *inlong_stream_id, const char *msg, int32_t msg_len);
 
-  AtomicInt user_exit_flag_{0};
-  volatile bool init_flag_ = false;
   volatile bool inited_ = false;
   volatile bool init_succeed_ = false;
-  AtomicInt buf_full_{0};
+  volatile bool exit_flag_ = false;
+
   uint32_t max_msg_length_;
   std::string local_ip_;
 
@@ -67,5 +64,5 @@ private:
   std::shared_ptr<SendManager> send_manager_;
 };
 
-} // namespace inlong
-#endif // INLONG_SDK_API_IMP_H
+}  // namespace inlong
+#endif  // INLONG_API_IMP_H
