@@ -165,7 +165,7 @@ public class PulsarMultiTopicsFetcher extends MultiTopicsFetcher {
                     .collect(Collectors.toList());
             Consumer<byte[]> consumer = pulsarClient.newConsumer(Schema.BYTES)
                     .topics(topicNames)
-                    .subscriptionName(context.getConfig().getSortTaskId())
+                    .subscriptionName(context.getConfig().getSubscription())
                     .subscriptionType(SubscriptionType.Shared)
                     .startMessageIdInclusive()
                     .subscriptionInitialPosition(position)
